@@ -16,7 +16,7 @@ from utilities.forms import (
 )
 
 from netbox_storage.models import Drive
-from virtualization.models import Cluster, ClusterType, VirtualMachine
+from virtualization.models import Cluster, VirtualMachine
 
 
 class DriveForm(NetBoxModelForm):
