@@ -60,6 +60,27 @@ class Migration(migrations.Migration):
                 "ordering": ("size", "id"),
             },
         ),
+        migrations.CreateModel(
+            name="VolumeGroup",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("vg_name", models.CharField(max_length=255)),
+                ("description", models.CharField(max_length=255)),
+            ],
+            options={
+                "ordering": ("lv_name", "id"),
+            },
+        ),
         migrations.CreateModel(
             name="PhysicalVolume",
             fields=[
@@ -75,8 +96,11 @@ class Migration(migrations.Migration):
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
                 ("partition",
-                 models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="partition_physicalvolume",
+                 models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="partition_physicalvolume",
                                    to="netbox_storage.partition")),
+                ("vg",
+                 models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="volumegroup_physicalvolume",
+                                   to="netbox_storage.volumegroup")),
                 ("pv_name", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
             ],
@@ -105,27 +129,6 @@ class Migration(migrations.Migration):
                 "ordering": ("filesystem", "id"),
             },
         ),
-        migrations.CreateModel(
-            name="VolumeGroup",
-            fields=[
-                ("created", models.DateTimeField(auto_now_add=True, null=True)),
-                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
-                (
-                    "custom_field_data",
-                    models.JSONField(
-                        blank=True,
-                        default=dict,
-                        encoder=utilities.json.CustomFieldJSONEncoder
-                    ),
-                ),
-                ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("vg_name", models.CharField(max_length=255)),
-                ("description", models.CharField(max_length=255)),
-            ],
-            options={
-                "ordering": ("lv_name", "id"),
-            },
-        ),
         migrations.CreateModel(
             name="LogicalVolume",
             fields=[
@@ -148,6 +151,7 @@ class Migration(migrations.Migration):
                 ("fs",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_linux',
                                    to='netbox_storage.filesystem')),
+                ("size", models.PositiveIntegerField()),
                 ("description", models.CharField(max_length=255)),
             ],
             options={
