@@ -126,36 +126,7 @@ class Partition(NetBoxModel):
         return PhysicalVolume.objects.filter(partition=self).count()
 
 
-class PhysicalVolume(NetBoxModel):
-    partition = models.ForeignKey(
-        Partition,
-        on_delete=models.CASCADE,
-        related_name='partition_physicalvolume',
-    )
-    pv_name = models.CharField(
-        max_length=255,
-    )
-    description = models.CharField(
-        max_length=255,
-        blank=True,
-    )
-
-    clone_fields = [
-        "partition",
-        "pv_name",
-        "description",
-    ]
-
-    def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:physicalvolume", kwargs={"pk": self.pk})
-
-    def __str__(self):
-        return self.pv_name
-
-    class Meta:
-        ordering = ("partition", "description")
-
-
+# In this example, a Reporter (vg) can be associated with many Article (pv) objects, but an Article (pv) can only have one Reporter (vg) object:
 class VolumeGroup(NetBoxModel):
     vg_name = models.CharField(
         max_length=255,
@@ -180,6 +151,46 @@ class VolumeGroup(NetBoxModel):
         ordering = ("vg_name", "description")
 
 
+class PhysicalVolume(NetBoxModel):
+    partition = models.ForeignKey(
+        Partition,
+        on_delete=models.CASCADE,
+        related_name='partition_physicalvolume',
+    )
+    pv_name = models.CharField(
+        max_length=255,
+    )
+    vg = models.ForeignKey(
+        VolumeGroup,
+        on_delete=models.CASCADE,
+        related_name='volumegroup_physicalvolume',
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = [
+        "partition",
+        "pv_name",
+        "vg",
+        "description",
+    ]
+
+    prerequisite_models = (
+        'netbox_storage.VolumeGroup',
+    )
+
+    def get_absolute_url(self):
+        return reverse("plugins:netbox_storage:physicalvolume", kwargs={"pk": self.pk})
+
+    def __str__(self):
+        return self.pv_name
+
+    class Meta:
+        ordering = ("partition", "description")
+
+
 class Filesystem(NetBoxModel):
     filesystem = models.CharField(
         unique=True,
@@ -203,7 +214,7 @@ class Filesystem(NetBoxModel):
 
 
 class LogicalVolume(NetBoxModel):
-    vg = models.ForeignKey(VolumeGroup, on_delete=models.CASCADE, related_name='volumegroup_logicalvolume',)
+    vg = models.ForeignKey(VolumeGroup, on_delete=models.CASCADE, related_name='volumegroup_logicalvolume')
     lv_name = models.CharField(
         max_length=255,
     )
@@ -225,6 +236,7 @@ class LogicalVolume(NetBoxModel):
     )
 
     clone_fields = [
+        "vg",
         "lv_name",
         "size",
         "path",
