@@ -2,7 +2,7 @@ from django.urls import path
 
 from netbox.views.generic import ObjectChangeLogView
 
-from netbox_storage.models import Drive, Filesystem, LinuxVolume, Partition, PhysicalVolume
+from netbox_storage.models import Drive, Filesystem, Partition, PhysicalVolume, VolumeGroup, LogicalVolume
 from netbox_storage.views import (
     # Drive View
     DriveListView,
@@ -20,14 +20,6 @@ from netbox_storage.views import (
     FilesystemBulkImportView,
     FilesystemBulkEditView,
     FilesystemBulkDeleteView,
-    # LinuxVolume
-    LinuxVolumeListView,
-    LinuxVolumeView,
-    LinuxVolumeDeleteView,
-    LinuxVolumeEditView,
-    LinuxVolumeBulkImportView,
-    LinuxVolumeBulkEditView,
-    LinuxVolumeBulkDeleteView,
     # Partition
     PartitionListView,
     PartitionEditView,
@@ -43,7 +35,25 @@ from netbox_storage.views import (
     PhysicalVolumeBulkEditView,
     PhysicalVolumeBulkDeleteView,
     PhysicalVolumeView,
-    PhysicalVolumeDeleteView, DrivePartitionListView, PartitionPhysicalVolumeListView,
+    PhysicalVolumeDeleteView,
+    DrivePartitionListView,
+    PartitionPhysicalVolumeListView,
+    # VolumeGroup
+    VolumeGroupListView,
+    VolumeGroupEditView,
+    VolumeGroupBulkImportView,
+    VolumeGroupBulkEditView,
+    VolumeGroupView,
+    VolumeGroupDeleteView,
+    VolumeGroupBulkDeleteView,
+    # LogicalVolume
+    LogicalVolumeListView,
+    LogicalVolumeEditView,
+    LogicalVolumeBulkImportView,
+    LogicalVolumeBulkEditView,
+    LogicalVolumeBulkDeleteView,
+    LogicalVolumeView,
+    LogicalVolumeDeleteView,
 )
 
 app_name = "netbox_storage"
@@ -85,23 +95,6 @@ urlpatterns = [
         kwargs={"model": Filesystem},
     ),
     #
-    # LinuxVolume urls
-    #
-    path("linuxvolume/", LinuxVolumeListView.as_view(), name="linuxvolume_list"),
-    path("linuxvolume/add/", LinuxVolumeEditView.as_view(), name="linuxvolume_add"),
-    path("linuxvolume/import/", LinuxVolumeBulkImportView.as_view(), name="linuxvolume_import"),
-    path("linuxvolume/edit/", LinuxVolumeBulkEditView.as_view(), name="linuxvolume_bulk_edit"),
-    path("linuxvolume/delete/", LinuxVolumeBulkDeleteView.as_view(), name="linuxvolume_bulk_delete"),
-    path("linuxvolume/<int:pk>/", LinuxVolumeView.as_view(), name="linuxvolume"),
-    path("linuxvolume/<int:pk>/edit/", LinuxVolumeEditView.as_view(), name="linuxvolume_edit"),
-    path("linuxvolume/<int:pk>/delete/", LinuxVolumeDeleteView.as_view(), name="linuxvolume_delete"),
-    path(
-        "linuxvolume/<int:pk>/changelog/",
-        ObjectChangeLogView.as_view(),
-        name="linuxvolume_changelog",
-        kwargs={"model": LinuxVolume},
-    ),
-    #
     # Partition urls
     #
     path("partition/", PartitionListView.as_view(), name="partition_list"),
@@ -138,4 +131,38 @@ urlpatterns = [
         name="physicalvolume_changelog",
         kwargs={"model": PhysicalVolume},
     ),
+    #
+    # VolumeGroup urls
+    #
+    path("volumegroup/", VolumeGroupListView.as_view(), name="volumegroup_list"),
+    path("volumegroup/add/", VolumeGroupEditView.as_view(), name="volumegroup_add"),
+    path("volumegroup/import/", VolumeGroupBulkImportView.as_view(), name="volumegroup_import"),
+    path("volumegroup/edit/", VolumeGroupBulkEditView.as_view(), name="volumegroup_bulk_edit"),
+    path("volumegroup/delete/", VolumeGroupBulkDeleteView.as_view(), name="volumegroup_bulk_delete"),
+    path("volumegroup/<int:pk>/", VolumeGroupView.as_view(), name="volumegroup"),
+    path("volumegroup/<int:pk>/edit/", VolumeGroupEditView.as_view(), name="volumegroup_edit"),
+    path("volumegroup/<int:pk>/delete/", VolumeGroupDeleteView.as_view(), name="volumegroup_delete"),
+    path(
+        "volumegroup/<int:pk>/changelog/",
+        ObjectChangeLogView.as_view(),
+        name="volumegroup_changelog",
+        kwargs={"model": VolumeGroup},
+    ),
+    #
+    # LogicalVolume urls
+    #
+    path("logicalvolume/", LogicalVolumeListView.as_view(), name="logicalvolume_list"),
+    path("logicalvolume/add/", LogicalVolumeEditView.as_view(), name="logicalvolume_add"),
+    path("logicalvolume/import/", LogicalVolumeBulkImportView.as_view(), name="logicalvolume_import"),
+    path("logicalvolume/edit/", LogicalVolumeBulkEditView.as_view(), name="logicalvolume_bulk_edit"),
+    path("logicalvolume/delete/", LogicalVolumeBulkDeleteView.as_view(), name="logicalvolume_bulk_delete"),
+    path("logicalvolume/<int:pk>/", LogicalVolumeView.as_view(), name="logicalvolume"),
+    path("logicalvolume/<int:pk>/edit/", LogicalVolumeEditView.as_view(), name="logicalvolume_edit"),
+    path("logicalvolume/<int:pk>/delete/", LogicalVolumeDeleteView.as_view(), name="logicalvolume_delete"),
+    path(
+        "logicalvolume/<int:pk>/changelog/",
+        ObjectChangeLogView.as_view(),
+        name="logicalvolume_changelog",
+        kwargs={"model": LogicalVolume},
+    ),
 ]
